@@ -208,16 +208,23 @@ ll_args.stanreg <- function(object, newdata = NULL, offset = NULL, m = NULL,
   has_newdata <- !is.null(newdata)
   
   dots <- list(...)
+  
+  z_betareg <- NULL
   if (has_newdata && reloo_or_kfold && !is.mer(object)) {
     x <- dots$newx
+    z_betareg <- dots$newz # NULL except for some stan_betareg models
+    if (!is.null(z_betareg)) {
+      z_betareg <- as.matrix(z_betareg)
+    }
     stanmat <- dots$stanmat
     form <- as.formula(formula(object)) # in case formula is string
     y <- eval(form[[2L]], newdata)
   } else if (has_newdata) {
     ppdat <- pp_data(object, as.data.frame(newdata), offset = offset, m = m)
-    tmp <- pp_eta(object, ppdat, m = m)
-    eta <- tmp$eta
-    stanmat <- tmp$stanmat
+    pp_eta_dat <- pp_eta(object, ppdat, m = m)
+    eta <- pp_eta_dat$eta
+    stanmat <- pp_eta_dat$stanmat
+    z_betareg <- ppdat$z_betareg
     x <- ppdat$x
     form <- as.formula(formula(object, m = m))
     y <- eval(form[[2L]], newdata)
@@ -245,6 +252,9 @@ ll_args.stanreg <- function(object, newdata = NULL, offset = NULL, m = NULL,
       
     } else if (!is.binomial(fname)) {
       data <- data.frame(y, x)
+      if (!is.null(z_betareg)) {
+        data <- cbind(data, z_betareg)
+      }
     } else {
       if (NCOL(y) == 2L) {
         trials <- rowSums(y)
@@ -286,19 +296,27 @@ ll_args.stanreg <- function(object, newdata = NULL, offset = NULL, m = NULL,
       if (length(z_vars) == 1 && z_vars == "(phi)") {
         draws$phi <- stanmat[, z_vars]
       } else {
-        x_dat <- get_x(object)
-        z_dat <- object$z
-        colnames(x_dat) <- colnames(x_dat)
-        colnames(z_dat) <- paste0("(phi)_", colnames(z_dat))
-        data <- data.frame(y = get_y(object), cbind(x_dat, z_dat), check.names = FALSE)
+        if (has_newdata) {
+          if (!is.null(z_betareg)) {
+          colnames(data) <- c("y", colnames(get_x(object)), 
+                              paste0("(phi)_", colnames(z_betareg)))
+          }
+        } else {
+          x_dat <- get_x(object)
+          z_dat <- as.matrix(object$z)
+          colnames(x_dat) <- colnames(x_dat)
+          colnames(z_dat) <- paste0("(phi)_", colnames(z_dat))
+          data <- data.frame(y = get_y(object), cbind(x_dat, z_dat), check.names = FALSE)
+        }
         draws$phi <- stanmat[,z_vars]
       }
     }
   } else {
     stopifnot(is_polr(object))
     y <- as.integer(y)
-    if (has_newdata) 
+    if (has_newdata) {
       x <- .validate_polr_x(object, x)
+    }
     data <- data.frame(y, x)
     draws$beta <- stanmat[, colnames(x), drop = FALSE]
     patt <- if (length(unique(y)) == 2L) "(Intercept)" else "|"
