@@ -37,6 +37,8 @@
 #' @return A ggplot object that can be further customized using the 
 #'   \pkg{ggplot2} package.
 #'   
+#' @template reference-bayesvis
+#' 
 #' @examples
 #' 
 #' \dontrun{
@@ -142,13 +144,15 @@ posterior_vs_prior.stanreg <-
     
     # draw from prior distribution and prepare plot data
     message("\nDrawing from prior...")
-    Prior <- suppressWarnings(update(
-      object,
-      prior_PD = TRUE,
-      refresh = -1,
-      iter = 2000,
-      chains = 2
-    ))
+    capture.output(
+      Prior <- suppressWarnings(update(
+        object,
+        prior_PD = TRUE,
+        refresh = -1,
+        iter = 2000,
+        chains = 2
+      ))
+    )
     objects <- nlist(Prior, Posterior = object)
     plot_data <-
       stack_estimates(objects,
