@@ -58,7 +58,19 @@
 #'   matrix and the remaining list elements collectively constitute a basis for a
 #'   smooth nonlinear function of the predictors indicated by the \code{formula}
 #'   argument to \code{\link{stan_gamm4}}.
-
+#' @param mean_PPD A logical value indicating whether the sample mean of the
+#'   posterior predictive distribution of the outcome should be calculated in
+#'   the \code{generated quantities} block. If \code{TRUE} then \code{mean_PPD}
+#'   is computed and displayed as a diagnostic in the
+#'   \link[=print.stanreg]{printed output}. The default is \code{TRUE} except if
+#'   \code{algorithm=="optimizing"}. A useful heuristic is to check if
+#'   \code{mean_PPD} is plausible when compared to \code{mean(y)}. If it is
+#'   plausible then this does \emph{not} mean that the model is good in general
+#'   (only that it can reproduce the sample mean), but if \code{mean_PPD} is
+#'   implausible then there may be something wrong, e.g., severe model
+#'   misspecification, problems with the data and/or priors, computational
+#'   issues, etc.
+#' 
 #' @details The \code{stan_glm} function is similar in syntax to 
 #'   \code{\link[stats]{glm}} but rather than performing maximum likelihood 
 #'   estimation of generalized linear models, full Bayesian estimation is 
@@ -77,10 +89,18 @@
 #' @examples
 #' if (!grepl("^sparc",  R.version$platform)) {
 #' ### Linear regression
-#' fit <- stan_glm(mpg / 10 ~ ., data = mtcars, QR = TRUE,
-#'                 algorithm = "fullrank") # for speed of example only
+#' mtcars$mpg10 <- mtcars$mpg / 10
+#' fit <- stan_glm(
+#'   mpg10 ~ wt + cyl + am,            
+#'   data = mtcars, 
+#'   QR = TRUE,
+#'   # for speed of example only (default is "sampling")
+#'   algorithm = "fullrank" 
+#'  ) 
+#'                 
 #' plot(fit, prob = 0.5)
 #' plot(fit, prob = 0.5, pars = "beta")
+#' plot(fit, "hist", pars = "sigma")
 #' }
 #' \donttest{
 #' ### Logistic regression
@@ -92,48 +112,73 @@
 #'   family = binomial(link = "logit"), 
 #'   prior_intercept = normal(0, 10),
 #'   QR = TRUE,
-#'   chains = 2, iter = 200 # for speed of example only
+#'   # for speed of example only
+#'   chains = 2, iter = 200 
 #' )
 #' print(fit2)
 #' prior_summary(fit2)
 #' 
-#' plot(fit2, plotfun = "areas", prob = 0.9, # ?bayesplot::mcmc_areas
+#' # ?bayesplot::mcmc_areas
+#' plot(fit2, plotfun = "areas", prob = 0.9,
 #'      pars = c("(Intercept)", "arsenic"))
-#' pp_check(fit2, plotfun = "error_binned")  # ?bayesplot::ppc_error_binned
+#' 
+#' # ?bayesplot::ppc_error_binned
+#' pp_check(fit2, plotfun = "error_binned") 
 #' 
 #' 
 #' ### Poisson regression (example from help("glm")) 
-#' counts <- c(18,17,15,20,10,20,25,13,12)
-#' outcome <- gl(3,1,9)
-#' treatment <- gl(3,3)
-#' fit3 <- stan_glm(counts ~ outcome + treatment, family = poisson(link="log"),
-#'                  prior = normal(0, 1), prior_intercept = normal(0, 5),
-#'                  chains = 2, iter = 250) # for speed of example only
+#' count_data <- data.frame(
+#'  counts = c(18,17,15,20,10,20,25,13,12),
+#'  outcome = gl(3,1,9),
+#'  treatment = gl(3,3)
+#' )
+#' fit3 <- stan_glm(
+#'   counts ~ outcome + treatment, 
+#'   data = count_data, 
+#'   family = poisson(link="log"),
+#'   prior = normal(0, 2, autoscale = FALSE),
+#'   # for speed of example only
+#'   chains = 2, iter = 250 
+#' ) 
 #' print(fit3)
 #' 
-#' bayesplot::color_scheme_set("green")
+#' bayesplot::color_scheme_set("viridis")
 #' plot(fit3)
 #' plot(fit3, regex_pars = c("outcome", "treatment"))
 #' plot(fit3, plotfun = "combo", regex_pars = "treatment") # ?bayesplot::mcmc_combo
+#' posterior_vs_prior(fit3, regex_pars = c("outcome", "treatment"))
 #' 
 #' ### Gamma regression (example from help("glm"))
 #' clotting <- data.frame(log_u = log(c(5,10,15,20,30,40,60,80,100)),
 #'                        lot1 = c(118,58,42,35,27,25,21,19,18),
 #'                        lot2 = c(69,35,26,21,18,16,13,12,12))
-#' fit4 <- stan_glm(lot1 ~ log_u, data = clotting, family = Gamma(link="log"),
-#'                  chains = 2, iter = 300) # for speed of example only 
+#' fit4 <- stan_glm(
+#'   lot1 ~ log_u, 
+#'   data = clotting, 
+#'   family = Gamma(link="log"),
+#'   iter = 500 # for speed of example only 
+#'  ) 
 #' print(fit4, digits = 2)
+#' 
 #' fit5 <- update(fit4, formula = lot2 ~ log_u)
 #' 
+#' # ?bayesplot::ppc_dens_overlay
+#' bayesplot::bayesplot_grid(
+#'   pp_check(fit4, seed = 123), 
+#'   pp_check(fit5, seed = 123),
+#'   titles = c("lot1", "lot2")
+#' ) 
+#' 
+#' 
 #' ### Negative binomial regression
 #' fit6 <- stan_glm.nb(Days ~ Sex/(Age + Eth*Lrn), data = MASS::quine, 
-#'                     link = "log", prior_aux = exponential(1),
+#'                     link = "log", prior_aux = exponential(1.5),
 #'                     chains = 2, iter = 200) # for speed of example only
 #' 
 #' prior_summary(fit6)
 #' bayesplot::color_scheme_set("brightblue")
 #' plot(fit6)
-#' pp_check(fit6, plotfun = "hist", nreps = 5)
+#' pp_check(fit6, plotfun = "hist", nreps = 5) # ?bayesplot::ppc_hist
 #' 
 #' # 80% interval of estimated reciprocal_dispersion parameter
 #' posterior_interval(fit6, pars = "reciprocal_dispersion", prob = 0.8)
@@ -158,6 +203,7 @@ stan_glm <-
            prior_aux = exponential(),
            prior_PD = FALSE,
            algorithm = c("sampling", "optimizing", "meanfield", "fullrank"),
+           mean_PPD = algorithm != "optimizing",
            adapt_delta = NULL,
            QR = FALSE,
            sparse = FALSE) {
@@ -169,9 +215,10 @@ stan_glm <-
   
   call <- match.call(expand.dots = TRUE)
   mf <- match.call(expand.dots = FALSE)
-  m <- match(c("formula", "data", "subset", "weights", "na.action", "offset"), 
+  m <- match(c("formula", "subset", "weights", "na.action", "offset"), 
              table = names(mf), nomatch = 0L)
   mf <- mf[c(1L, m)]
+  mf$data <- data
   mf$drop.unused.levels <- TRUE
   mf[[1L]] <- as.name("model.frame")
   mf <- eval(mf, parent.frame())
@@ -189,23 +236,39 @@ stan_glm <-
     weights <- double(0)
   }
 
-  stanfit <- stan_glm.fit(x = X, y = Y, weights = weights, 
-                          offset = offset, family = family,
-                          prior = prior, 
-                          prior_intercept = prior_intercept,
-                          prior_aux = prior_aux,
-                          prior_PD = prior_PD, 
-                          algorithm = algorithm, adapt_delta = adapt_delta, 
-                          QR = QR, sparse = sparse, ...)
-  if (family$family == "Beta regression") family$family <- "beta"
+  stanfit <- stan_glm.fit(
+    x = X,
+    y = Y,
+    weights = weights,
+    offset = offset,
+    family = family,
+    prior = prior,
+    prior_intercept = prior_intercept,
+    prior_aux = prior_aux,
+    prior_PD = prior_PD,
+    algorithm = algorithm,
+    mean_PPD = mean_PPD,
+    adapt_delta = adapt_delta,
+    QR = QR,
+    sparse = sparse,
+    ...
+  )
+  if (algorithm != "optimizing" && !is(stanfit, "stanfit")) return(stanfit)
+  if (family$family == "Beta regression") {
+    family$family <- "beta"
+  }
+  
   sel <- apply(X, 2L, function(x) !all(x == 1) && length(unique(x)) < 2)
   X <- X[ , !sel, drop = FALSE]  
+  
   fit <- nlist(stanfit, algorithm, family, formula, data, offset, weights,
                x = X, y = Y, model = mf,  terms = mt, call, 
                na.action = attr(mf, "na.action"), 
                contrasts = attr(X, "contrasts"), 
                stan_function = "stan_glm")
+  
   out <- stanreg(fit)
+  out$compute_mean_PPD <- mean_PPD
   out$xlevels <- .getXlevels(mt, mf)
   if (!x) 
     out$x <- NULL
@@ -240,6 +303,7 @@ stan_glm.nb <-
            prior_aux = exponential(),
            prior_PD = FALSE,
            algorithm = c("sampling", "optimizing", "meanfield", "fullrank"),
+           mean_PPD = algorithm != "optimizing",
            adapt_delta = NULL,
            QR = FALSE) {
     
