@@ -21,6 +21,6 @@ Sys.unsetenv("R_TESTS")
 # options(error = function() traceback(2))
 example(example_model)
 if (!grepl("^sparc",  R.version$platform)) 
-  test_check("rstanarm", invert = TRUE,
-             filter = if (Sys.getenv("NOT_CRAN") != "true") "jm|mvmer")
+  test_check("rstanarm", invert = FALSE,
+             filter = if (Sys.getenv("NOT_CRAN") != "true") "functions")
 
